@@ -186,6 +186,10 @@ class TestMessageHelpers:
     def test_parse_doi(self, doi, expected):
         assert message_helpers.parse_doi(doi) == expected
 
+    def test_fetch_dataset(self):
+        dataset = message_helpers.fetch_dataset("ord_dataset-35a5a513f1dd44a3a97c88da99f81a00")
+        assert len(dataset.reactions) == 7
+
 
 class TestFindSubmessages:
     def test_scalar(self):
@@ -435,7 +439,7 @@ class TestLoadAndWriteMessage:
             # NOTE(kearnes): The decoder is not perfect; for example, it will
             # not be able to distinguish from a message with the same tags and
             # types (e.g. test_pb2.Scalar and test_pb2.RepeatedScalar).
-            with pytest.raises(ValueError, match="Error parsing message"):
+            with pytest.raises(ValueError, match="parsing"):
                 message_helpers.load_message(f.name, test_pb2.Nested)
 
     def test_bad_json(self):
